==> haskell-hasql-transaction-0.5.2-86-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-transaction
version: 0.5.2
id: hasql-transaction-0.5.2-1My37CPUAi23AdZiWZG0lE
key: hasql-transaction-0.5.2-1My37CPUAi23AdZiWZG0lE
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-transaction
synopsis: A composable abstraction over the retryable transactions for Hasql
category: Hasql, Database, PostgreSQL
abi: 1a5ed51ae6e2da1b4a1f6458723905cd
exposed: True
exposed-modules:
    Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules: Hasql.Transaction.Private.Prelude
                Hasql.Transaction.Private.Model Hasql.Transaction.Private.SQL
                Hasql.Transaction.Private.Queries
                Hasql.Transaction.Private.Sessions
                Hasql.Transaction.Private.Transaction
import-dirs: /usr/lib/ghc-8.4.3/site-local/hasql-transaction-0.5.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/hasql-transaction-0.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hasql-transaction-0.5.2
hs-libraries: HShasql-transaction-0.5.2-1My37CPUAi23AdZiWZG0lE
depends:
    hasql-1.1.1-9z7WrhARfyvB9DJlpzkiLw
    bytestring-tree-builder-0.2.7.1-CRk5yk559FCKembl1gC1ra
    bytestring-0.10.8.2 contravariant-1.4.1-HAsNOXS6UjNLhhUqovtoIr
    contravariant-extras-0.3.4-JCQKBj7kvwO5L5p7jVngui mtl-2.2.2
    transformers-0.5.5.0 base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
    base-4.11.1.0
abi-depends: hasql-1.1.1-9z7WrhARfyvB9DJlpzkiLw=236c250b35ef76261a95c7f51608c95e
             bytestring-tree-builder-0.2.7.1-CRk5yk559FCKembl1gC1ra=137646c08afffcbc3f39231903a46a43
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             contravariant-1.4.1-HAsNOXS6UjNLhhUqovtoIr=1c8446e86d39f5069240f7ab3c213859
             contravariant-extras-0.3.4-JCQKBj7kvwO5L5p7jVngui=b6ce53ed4053d6898d419ccde2fe7de9
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=9396e903f9c3781aaf5fd627a604df05
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock
haddock-html: /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-transaction-0.5.2-88-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-transaction
version: 0.5.2
id: hasql-transaction-0.5.2-1WVr3GA2U2NLiknsnZ68Lz
key: hasql-transaction-0.5.2-1WVr3GA2U2NLiknsnZ68Lz
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-transaction
synopsis: A composable abstraction over the retryable transactions for Hasql
category: Hasql, Database, PostgreSQL
abi: 81ea9466b5d7f767abf5014e0b60bceb
exposed: True
exposed-modules:
    Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules: Hasql.Transaction.Private.Prelude
                Hasql.Transaction.Private.Model Hasql.Transaction.Private.SQL
                Hasql.Transaction.Private.Queries
                Hasql.Transaction.Private.Sessions
                Hasql.Transaction.Private.Transaction
import-dirs: /usr/lib/ghc-8.4.3/site-local/hasql-transaction-0.5.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/hasql-transaction-0.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hasql-transaction-0.5.2
hs-libraries: HShasql-transaction-0.5.2-1WVr3GA2U2NLiknsnZ68Lz
depends:
    hasql-1.1.1-HBBptGIJGdpEzSSVsGFgAY
    bytestring-tree-builder-0.2.7.1-CRk5yk559FCKembl1gC1ra
    bytestring-0.10.8.2 contravariant-1.4.1-HAsNOXS6UjNLhhUqovtoIr
    contravariant-extras-0.3.4-JCQKBj7kvwO5L5p7jVngui mtl-2.2.2
    transformers-0.5.5.0 base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
    base-4.11.1.0
abi-depends: hasql-1.1.1-HBBptGIJGdpEzSSVsGFgAY=00f8448af85519c81fddafa8ecfd240c
             bytestring-tree-builder-0.2.7.1-CRk5yk559FCKembl1gC1ra=137646c08afffcbc3f39231903a46a43
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             contravariant-1.4.1-HAsNOXS6UjNLhhUqovtoIr=1c8446e86d39f5069240f7ab3c213859
             contravariant-extras-0.3.4-JCQKBj7kvwO5L5p7jVngui=b6ce53ed4053d6898d419ccde2fe7de9
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=9396e903f9c3781aaf5fd627a604df05
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock
haddock-html: /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
